import sys
import typing

GenericType = typing.TypeVar("GenericType")


def add_node_type(layout, node_type, label):
    ''' 

    '''

    pass


def draw_node_group_add_menu(context, layout):
    ''' 

    '''

    pass
